AutoPlanner
===========

Explications :

  * pas de  


  * génération d'un .ics global et d'ICS pour chaque personne
  * afficher un calendrier
  * statistiques par personne et par catégorie (# événements et temps total)
  * respect des contraintes (#temps min, #temps max)
  * limiter les agents possibles à ceux de l'organisation 
  * limiter les catégories possibles à celles de l'organisation
  * créer un token par agent
  * faire une action pour fixer les agents sur les tâches
  * faire un bouton pour fixer les agents des tâches passées
  * ajouter le bonus pour les tâches 
